summaryrefslogtreecommitdiffstats
path: root/chrome/browser/site_instance_unittest.cc
diff options
context:
space:
mode:
authorbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
committerbrettw@chromium.org <brettw@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-05-04 07:58:34 +0000
commit57c6a6579cf274fe37d6196931a3034d90da7113 (patch)
treeec42313580156ccc039b5fee714ee12259cb08ee /chrome/browser/site_instance_unittest.cc
parentb23c9e1f05d474adc327c85d87eacc77554976e0 (diff)
downloadchromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.zip
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.gz
chromium_src-57c6a6579cf274fe37d6196931a3034d90da7113.tar.bz2
Replace all occurrances of WebContents with TabContents.
Review URL: http://codereview.chromium.org/99177 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@15194 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/site_instance_unittest.cc')
-rw-r--r--chrome/browser/site_instance_unittest.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/chrome/browser/site_instance_unittest.cc b/chrome/browser/site_instance_unittest.cc
index 7dd850f..d0068d6 100644
--- a/chrome/browser/site_instance_unittest.cc
+++ b/chrome/browser/site_instance_unittest.cc
@@ -7,7 +7,7 @@
#include "chrome/browser/renderer_host/render_view_host.h"
#include "chrome/browser/renderer_host/test_render_view_host.h"
#include "chrome/browser/tab_contents/navigation_entry.h"
-#include "chrome/browser/tab_contents/web_contents.h"
+#include "chrome/browser/tab_contents/tab_contents.h"
#include "chrome/common/render_messages.h"
#include "chrome/test/testing_profile.h"
#include "testing/gtest/include/gtest/gtest.h"
@@ -69,7 +69,7 @@ class TestSiteInstance : public SiteInstance {
// Test to ensure no memory leaks for SiteInstance objects.
TEST_F(SiteInstanceTest, SiteInstanceDestructor) {
// The existance of these factories will cause WebContents to create our test
// one instead of the real one.
MockRenderProcessHostFactory rph_factory;
TestRenderViewHostFactory rvh_factory(&rph_factory);
@@ -113,12 +113,12 @@ TEST_F(SiteInstanceTest, SiteInstanceDestructor) {
&siteDeleteCounter,
&browsingDeleteCounter);
{
- WebContents contents(profile.get(), instance, MSG_ROUTING_NONE, NULL);
+ TabContents contents(profile.get(), instance, MSG_ROUTING_NONE, NULL);
EXPECT_EQ(1, siteDeleteCounter);
EXPECT_EQ(1, browsingDeleteCounter);
}
// Make sure that we flush any messages related to the above WebContents
// destruction.
MessageLoop::current()->RunAllPending();
@@ -69,7 +69,7 @@ class TestSiteInstance : public SiteInstance {
// Test to ensure no memory leaks for SiteInstance objects.
TEST_F(SiteInstanceTest, SiteInstanceDestructor) {
- // The existance of these factories will cause WebContents to create our test
+ // The existance of these factories will cause TabContents to create our test
// one instead of the real one.
MockRenderProcessHostFactory rph_factory;
@@ -113,12 +113,12 @@ TEST_F(SiteInstanceTest, SiteInstanceDestructor) {
EXPECT_EQ(1, browsingDeleteCounter);
}
- // Make sure that we flush any messages related to the above WebContents
+ // Make sure that we flush any messages related to the above TabContents
// destruction.
MessageLoop::current()->RunAllPending();